/* Pretty Print Node List */
/* Contributed to public domain by Tom Almy, 1996 */
#include <stdio.h>
#include <string.h>
#include <ctype.h>

char line[256];
char id[32];		/* parsed fields */
char num[32];
char sysname[64];
char loc[64];
char name[64];

int zone;
int net;
int node;

unsigned zccount;  /* zone */
unsigned rccount;  /* region */
unsigned nccount;  /* host */
unsigned hubcount; /* hub */
unsigned nodecount; /* node */
unsigned downcount; /* down */

void printinfo(int indent) {
	int pos;

	pos = printf("%*s%d:%d/%d",indent, "", zone, net, node);
	printf("%*s%-20.19s%-18.17s%-20.19s\n",18-pos,"",sysname,loc,name);
}

void main(void) {
	char *src, *dst;
	unsigned value;
	fprintf(stderr, "Pretty Print Node List V1.0\n"
			"Copyright 1996, Thomas Almy\n"
			"May be freely distributed providing no charge is made\n"
			"beyond cost of distribution\n");
	while (fgets(line, 256, stdin) != NULL) {
		if (line[0] == '\0' || line[0] == ';') {
			continue;
		}
		src = line;
		dst = id;
		while (*src != ',' && *src != '\0') *dst++ = toupper(*src++);
		*dst = '\0';
		src++;
		dst = num;
		while (*src != ',' && *src != '\0') *dst++ = *src++;
		*dst = '\0';
		sscanf(num, "%u", &value);
		src++;
		dst = sysname;
		while (*src != ',' && *src != '\0') {
			if (*src == '_') {
				*dst++ = ' ';
				src++;
			}
			else *dst++ = *src++;
		}
		*dst = '\0';
		src++;
		dst = loc;
		while (*src != ',' && *src != '\0') {
			if (*src == '_') {
				*dst++ = ' ';
				src++;
			}
			else *dst++ = *src++;
		}
		*dst = '\0';
		src++;
		dst = name;
		while (*src != ',' && *src != '\0') {
			if (*src == '_') {
				*dst++ = ' ';
				src++;
			}
			else *dst++ = *src++;
		}
		*dst = '\0';
		if (strcmp("ZONE", id)==0) { /* new zone */
			zone = net = value;
			node = 0;
			zccount++;
			printinfo(0);
		}
		else if (strcmp("REGION", id) == 0) { /* new region */
			net = value;
			node = 0;
			rccount++;
			printinfo(1);
		}
		else if (strcmp("HOST", id) == 0) { /* new net */
			net = value;
			node = 0;
			nccount++;
			printinfo(2);
		}
		else if (strcmp("HUB", id) == 0) { /* new hub */
			node = value;
			hubcount++;
			printinfo(3);
		}
		else if (strcmp("DOWN", id) == 0) { /* down nodes -- don't list */
			downcount++;
		}
		else { /* nodes */
			node = value;
			nodecount++;
			printinfo(4);
		}
	}
	printf("\n\nTotals:\n"
		   "  Zones   - %d\n"
		   "  Regions - %d\n"
		   "  Nets    - %d\n"
		   "  Hubs    - %d\n"
		   "  Nodes   - %d\n"
		   " (Down    - %d)\n", zccount, rccount, nccount,
		   hubcount, nodecount, downcount);
}